package pomodoro

import (
	"git.smsvc.net/pomodoro/GoTomato/internal/broadcast"
	"git.smsvc.net/pomodoro/GoTomato/pkg/models"
	"github.com/gorilla/websocket"
	"time"
)

var timerRunning bool
var timerStopChannel = make(chan bool, 1)

// startTimer runs the countdown and broadcasts every second.
func startTimer(clients map[*websocket.Conn]bool, remainingSeconds int, mode string, session int) bool {
	for remainingSeconds > 0 {
		select {
		case <-timerStopChannel:
			return false // Stop the timer if a stop command is received
		default:
			// Broadcast the current state to all clients
			broadcast.BroadcastMessage(clients, models.BroadcastMessage{
				Mode:       mode,
				Session:    session,
				MaxSession: sessions,
				TimeLeft:   remainingSeconds,
			})
			time.Sleep(time.Second)
			remainingSeconds--
		}
	}

	// Final broadcast when time reaches zero
	broadcast.BroadcastMessage(clients, models.BroadcastMessage{
		Mode:       mode,
		Session:    session,
		MaxSession: sessions,
		TimeLeft:   0,
	})

	return true
}

// StopTimer sends a signal to stop the running Pomodoro timer.
func StopTimer() {
	timerStopChannel <- true
}

// IsTimerRunning returns the status of the timer.
func IsTimerRunning() bool {
	return timerRunning
}
